@@ -15,8 +15,6 @@ def quaternion_to_euler(
     """
     rotation_object: Rotation = Rotation.from_quat(quaternion.as_np_array())
     euler: Euler = Euler.from_array(
-        rotation_object.as_euler(sequence, degrees=degrees),
-        from_="robot",
-        to_="asset",
+        rotation_object.as_euler(sequence, degrees=degrees), frame="robot"
     )
     return euler
