@@ -5,6 +5,7 @@ from pathlib import Path
 from dacite import from_dict
 
 from alitra.frame_dataclasses import PointList
+from alitra.models.bounds import Bounds
 
 
 @dataclass
@@ -12,6 +13,7 @@ class MapConfig:
     map_name: str
     robot_reference_points: PointList
     asset_reference_points: PointList
+    bounds: Bounds = None
 
 
 def load_map_config(map_config_path: Path) -> MapConfig:
